@@ -135,10 +135,41 @@ def oi_chain_builder (symbol,expiry="latest",oi_mode="full"):
 
     return oi_data,float(payload['records']['underlyingValue']),payload['records']['timestamp']
 
-
 def get_atm_strike(symbol): #Thanks to Ronit_Hain and Ankit Jain
     payload = nse_optionchain_scrapper(symbol.upper())
     ltp = float(payload['records']['underlyingValue'])
     strike_price_list = [x['strikePrice'] for x in payload['records']['data']]
     atm_strike = sorted([[round(abs(ltp-i),2),i] for i in strike_price_list])[0][1]
     return atm_strike
+
+def running_status(): #It will give true if market is running and false if market is not running.
+    start_now=datetime.datetime.now().replace(hour=9, minute=15, second=0, microsecond=0)
+    end_now=datetime.datetime.now().replace(hour=15, minute=45, second=0, microsecond=0)
+    return start_now<datetime.datetime.now()<end_now
+
+def nse_eq(symbol):
+    try:
+        payload = requests.get('https://www.nseindia.com/api/quote-equity?symbol='+symbol.replace('&','%26'),headers=headers).json()
+        try:
+            if(payload['error']=={}):
+                print("Please use nse_fno() function to reduce latency.")
+                payload = requests.get('https://www.nseindia.com/api/quote-derivative?symbol='+symbol.replace('&','%26'),headers=headers).json()
+        except:
+            pass
+    except KeyError:
+        print("Getting Error While Fetching.")
+    return payload
+
+
+def nse_fno(symbol):
+    try:
+        payload = requests.get('https://www.nseindia.com/api/quote-derivative?symbol='+symbol.replace('&','%26'),headers=headers).json()
+        try:
+            if(payload['error']=={}):
+                print("Please use nse_eq() function to reduce latency.")
+                payload = requests.get('https://www.nseindia.com/api/quote-equity?symbol='+symbol.replace('&','%26'),headers=headers).json()
+        except KeyError:
+            pass
+    except KeyError:
+        print("Getting Error While Fetching.")
+    return payload
